<img src="https://cdn.discordapp.com/attachments/839022894620999722/942197829701615676/Frame_2_1.png" height="100px" />
<hr>

### Reinvent your input.



SigLo is a python program that uses computer vision to use gestures to interact with their computer naturally.

<p float="left">

<img src="https://user-images.githubusercontent.com/30753067/153731247-5786df45-5c81-4c7b-8564-374e4d43856c.png" width="50px" />
<img src="https://upload.wikimedia.org/wikipedia/commons/thumb/3/32/OpenCV_Logo_with_text_svg_version.svg/1200px-OpenCV_Logo_with_text_svg_version.svg.png" width="50px"/>
<img src="https://viz.mediapipe.dev/logo.png" width="50px"/>
</p>

## Usage
### Swipe Gesture for switching slides during a presentation
<img src="https://github.com/AndreyPiterkin/SigLo/blob/main/images/slides-swapping.gif?raw=true" height="350px" />
Note: During a presentation, the camera view will be hidden and the presentation will be full-screen

### Scrolling gesture for scrolling through a webpage
<img src="https://github.com/AndreyPiterkin/SigLo/blob/main/images/website-scrolling.gif?raw=true" height="350px" />

### Horizontal and vertical supported
<img src="https://github.com/AndreyPiterkin/SigLo/blob/main/images/excel-scrolling.gif?raw=true" height="350px" />

### Online Video Seeking
<img src="https://github.com/AndreyPiterkin/SigLo/blob/main/images/youtube-video.gif?raw=true" height="350px" />

## Installation

1. Clone the repo
2. Install dependencies
```bash
pip install mediapipe pynput
```
3. Run the main python file
```bash
python3 driver.py
```

*A [HackBeanpot](https://hackbeanpot.com/) 2022 Submission*

## License
[MIT](https://choosealicense.com/licenses/mit/)
